@@ -1,4 +1,5 @@
 from patchwork.steps.AgenticLLM.AgenticLLM import AgenticLLM
+from patchwork.steps.AgenticLLMV2.AgenticLLMV2 import AgenticLLMV2
 from patchwork.steps.AnalyzeImpact.AnalyzeImpact import AnalyzeImpact
 from patchwork.steps.CallAPI.CallAPI import CallAPI
 from patchwork.steps.CallCode2Prompt.CallCode2Prompt import CallCode2Prompt
@@ -40,6 +41,7 @@ from patchwork.steps.PR.PR import PR
 from patchwork.steps.PreparePR.PreparePR import PreparePR
 from patchwork.steps.PreparePrompt.PreparePrompt import PreparePrompt
 from patchwork.steps.QueryEmbeddings.QueryEmbeddings import QueryEmbeddings
+from patchwork.steps.ReadEmail.ReadEmail import ReadEmail
 from patchwork.steps.ReadFile.ReadFile import ReadFile
 from patchwork.steps.ReadIssues.ReadIssues import ReadIssues
 from patchwork.steps.ReadPRDiffs.ReadPRDiffs import ReadPRDiffs
@@ -61,6 +63,7 @@ SimplifiedLLMOncePB = SimplifiedLLMOnce
 
 __all__ = [
     "AgenticLLM",
+    "AgenticLLMV2",
     "AnalyzeImpact",
     "CallAPI",
     "CallCode2Prompt",
@@ -92,6 +95,7 @@ __all__ = [
     "PreparePrompt",
     "PRPB",
     "QueryEmbeddings",
+    "ReadEmail",
     "ReadFile",
     "ReadIssues",
     "ReadPRDiffs",
